@@ -7,12 +7,15 @@ V.ratio <- function(web){
   M <- nrow(web) #number of "samples"
   Tj <- colSums(web) #species "density" per sample j
   ni <- rowSums(web) #nr. of individuals per species i
+  p <- ni/N
 
-  sigma.i <- ni/N*(1-ni/N)
-  ST.2 <- 1/N*sum((Tj-mean(Tj))^2)
-  V <- ST.2 / sum( (sigma.i)^2)
+  sigma.i.2 <- p*(1-p)
+  S.T.2 <- 1/N*sum((Tj-mean(Tj))^2)
+  V <- S.T.2 / sum(sigma.i.2)
   V
 }
 #example:
 #data(Safariland)
-#V.ratio(Safariland)
\ No newline at end of file
+#V.ratio(Safariland)
+
+
